@@ -1186,6 +1186,8 @@ class Quip:
                         _json["variablePrefix"] = "var"    
                     else:
                         _json["variablePrefix"] = self.extension_name.replace("-", "_")
+                        if _json["variablePrefix"] > 20:
+                            _json["variablePrefix"] = "ext"
                 f.write(self.format_json(_json))
                 logging.debug("template.json file is updated")
         else:
